/*
+-------------------------------- DISCLAIMER ---------------------------------+
|                                                                             |
| This application program is provided to you free of charge as an example.   |
| Despite the considerable efforts of Euresys personnel to create a usable    |
| example, you should not assume that this program is error-free or suitable  |
| for any purpose whatsoever.                                                 |
|                                                                             |
| EURESYS does not give any representation, warranty or undertaking that this |
| program is free of any defect or error or suitable for any purpose. EURESYS |
| shall not be liable, in contract, in torts or otherwise, for any damages,   |
| loss, costs, expenses or other claims for compensation, including those     |
| asserted by third parties, arising out of or in connection with the use of  |
| this program.                                                               |
|                                                                             |
+-----------------------------------------------------------------------------+
*/

//
//  FirstExpert Project
//
//  MainFrame class definition
//  File: MainFrame.cpp
//////////////////////////////////////////////////////////////////////////////////

// Application Header
//////////////////////////////////////////////////////////////////////////////////
#include "FirstExpert.h"

// Macros
//////////////////////////////////////////////////////////////////////////////////
IMPLEMENT_CLASS(MainFrame, wxDocParentFrame)

// Event Table
//////////////////////////////////////////////////////////////////////////////////
BEGIN_EVENT_TABLE(MainFrame, wxDocParentFrame)
EVT_MENU(ID_ABOUT, MainFrame::OnAbout)
// + MultiCam FirstExpert sample program
EVT_CUSTOM(EG_EVT_REFRESH, -1, MainFrame::OnRefresh)
// - MultiCam FirstExpert sample program
END_EVENT_TABLE()

// Constructors 
//////////////////////////////////////////////////////////////////////////////////
// frame constructor
MainFrame::MainFrame(wxDocManager* manager, wxFrame *parent,
                     const wxString& title, const wxPoint& pos,const wxSize& size,long type)
                     : wxDocParentFrame(manager,parent,-1,title,pos,size,type)
{
    // set the frame icon
    SetIcon(wxICON(FirstExpert));

    // create menu bars
    wxMenu* multicamMenu = new wxMenu();
    wxMenu* helpMenu = new wxMenu();

    multicamMenu->Append(ID_GRAB,_("&Grab"),_("Grab one image"));
    multicamMenu->Append(wxID_EXIT, _("E&xit\tAlt-X"), _("Quit this program"));
    helpMenu->Append(ID_ABOUT, _("&About FirstExpert\tCtrl-A"), _("About FirstExpert"));

    // now append the freshly created menu to the menu bar...
    wxMenuBar *menuBar = new wxMenuBar();
    menuBar->Append(multicamMenu,_("&MultiCam"));
    menuBar->Append(helpMenu, _("&Help"));

    // ... and attach this menu bar to the frame
    SetMenuBar(menuBar);

    // create the toolbar 
    wxToolBar* toolbar = CreateToolBar();
    toolbar->AddTool(ID_GRAB, _("Grab"), wxICON(grab), _("Grab Image"));
    toolbar->AddTool(ID_ABOUT, _("About"), wxICON(help), _("About FirstExpert"));
    toolbar->Realize();

    // create a status bar just for fun (by default with 1 pane only)
    CreateStatusBar(2);
    SetStatusText(_("Ready"));

    m_pCanvas = new FirstExpertCanvas(this,NULL);
}

// Event Handlers 
//////////////////////////////////////////////////////////////////////////////////
void MainFrame::OnAbout(wxCommandEvent& event)
{
    // called when help - about is picked from the menu or toolbar
    wxString msg;
    msg.Printf(_(APPLICATION_COPYRIGHT));
    wxMessageBox(msg, _(APPLICATION_ABOUT), wxOK | wxICON_INFORMATION, this);
}

// Methods 
//////////////////////////////////////////////////////////////////////////////////

void MainFrame::SetViewPointer(FirstExpertView *pView)
{
    if (m_pCanvas)
    {
        m_pCanvas->SetViewPointer(pView);
        m_pCanvas->Refresh();
    }
}

// + MultiCam FirstExpert sample program
void MainFrame::OnRefresh(wxEvent& event)
{
    m_pCanvas->Refresh(false);
}
// - MultiCam FirstExpert sample program
